========================
 Invenio-Pages v1.0.0a2
========================

Invenio-Pages v1.0.0a2 was released on February 5, 2016.

About
-----

Static pages module for Invenio.

*This is an experimental developer preview release.*

What's new
----------

- Major refactoring for Invenio 3.
- Adds versioning support for pages.

Installation
------------

   $ pip install invenio-pages==1.0.0a2

Documentation
-------------

   http://pythonhosted.org/invenio-pages/

Happy hacking and thanks for flying Invenio-Pages.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-pages
|   URL: http://invenio-software.org
